@@ -2,14 +2,15 @@
 
 import numpy as np
 import hyperclip
-from matplotlib import pyplot as plt
+# from matplotlib import pyplot as plt
 from time import time
 
-n = 2
+n = 7
 m = 3
 
 hyperplanes = [hyperclip.Hyperplane().set_by_points(np.random.random((n,n))) for i_m in range(m)]
 
+
 st = time()
 X = np.random.random((10**6,n))
 
@@ -19,11 +20,13 @@ for hyp in hyperplanes:
 
 mc_time = time()-st
 
+
+hc = hyperclip.Hyperclip(cython=True).set_hyperplanes(hyperplanes)
 st = time()
-hc = hyperclip.Hyperclip().set_hyperplanes(hyperplanes)
 vol = hc.volume()
 
 hc_time = time() - st
 
-print('10**6 MonteCarlo :', id_pos_side.mean(), 'Hyperclip :', vol)
-print('10**6 MonteCarlo time :', mc_time, 'Hyperclip time :', hc_time)
\ No newline at end of file
+print('MonteCarlo :', round(id_pos_side.mean(),6), 'time :', round(mc_time,6))
+print('Hyperclip :', round(vol,6), 'time :', round(hc_time,6))
+
